## ############################################################################
##
## The 2022 Europe Report of the Lancet Countdown on Health and Climate Change:
##                 towards a climate resilient future
##
## Indicator 1.2.2: Drought Indicator
##
## ############################################################################
##
## Authors: 
## - Balakrishnan Solaraju Murali, ORCID: 0000-0003-0013-3295
## - Nube González Reviriego, ORCID: 0000-0002-5919-6701
##
## Contributor:
## - Prof. Rachel Lowe, ORCID: 0000-0003-3939-7343
##
## Contact information: balakrishnan.solaraju@bsc.es
## 
## ############################################################################

# Functions to estimate PET

PETx <- function(tmean_mod=NA, pre_mod=NA, tmax_mod=NA, tmin_mod=NA, pet_method=NA, lat, na.rm=TRUE){
 
  lat <- lat # For PET computation 
  


  if (pet_method=='thornthwaite') {
    
      ftime= as.numeric(dim(tmean_mod)['time'])
      n_sdates= as.numeric(dim(tmean_mod)['sdate'])

      tmean_mod_temp <- as.vector(tmean_mod)
      
      # Computing Potential EvapoTranspiration
      x_PET <- thornthwaite(tmean_mod_temp, lat=lat, na.rm=TRUE)
      PET <- array(x_PET, dim = c(ftime,n_sdates))

 } 

  if (pet_method=='hargreaves') {

    ftime= as.numeric(dim(tmax_mod)['time'])
    n_sdates= as.numeric(dim(tmax_mod)['sdate'])
    
    tmax_mod_temp <- as.vector(tmax_mod)
    tmin_mod_temp <- as.vector(tmin_mod)
    
    # Computing Potential EvapoTranspiration
    x_PET <- hargreaves(Tmin=tmin_mod_temp, Tmax=tmax_mod_temp, Ra = NA, lat = lat, Pre = NA, na.rm = FALSE)
    PET <- array(x_PET, dim = c(ftime,n_sdates))

 }
  
  if (pet_method=='hargreaves_modified') {
    
    for(ns in 1:n_sdates)
    {

        tmax_mod_temp <- tmax_mod[,ns]
        tmin_mod_temp <- tmin_mod[,ns]
        pre_mod_temp <- pre_mod[,ns]
        
        # Computing Potential EvapoTranspiration
        PET <- tmax_mod_temp*NA
        AccumD <- tmax_mod_temp*NA
        
        # Computation of PET
        x_PET <- hargreaves(Tmin=tmin_mod_temp, Tmax=tmax_mod_temp, Ra = NA, lat = lat, Pre = pre_mod_temp, na.rm = FALSE)
        PET[1:ftime,ns] <- x_PET      #dim <- (lon lat ft sd memb)
        
    }
  }
  
return(PET)
   
}
  
  
